diff --git a/public/versioning.js b/public/versioning.js
index d7620449..ba2b4e45 100644
--- a/public/versioning.js
+++ b/public/versioning.js
@@ -13,7 +13,7 @@
* Example: 1.102.2 -> Major version 1, Minor version 102, Patch version 2
*/
-const VERSION = "1.113.0";
+const VERSION = "1.114.0";
if (parseMapVersion(VERSION) !== VERSION) alert("versioning.js: Invalid format or parsing function");
{
diff --git a/src/index.html b/src/index.html
index e5d2c5f6..878f3947 100644
--- a/src/index.html
+++ b/src/index.html
@@ -8506,7 +8506,7 @@
-
+
@@ -8524,12 +8524,12 @@
-
+
-
+
@@ -8551,8 +8551,8 @@
-
-
+
+
diff --git a/public/modules/dynamic/auto-update.js b/public/modules/dynamic/auto-update.js
index e255930d..aaf63539 100644
--- a/public/modules/dynamic/auto-update.js
+++ b/public/modules/dynamic/auto-update.js
@@ -1107,8 +1107,8 @@ export function resolveVersionConflicts(mapVersion) {
}
- if (isOlderThan("1.113.0")) {
- // v1.113.0 moved labels data from SVG to data model
+ if (isOlderThan("1.114.0")) {
+ // v1.114.0 moved labels data from SVG to data model
// Migrate old SVG labels to pack.labels structure
if (!pack.labels || !pack.labels.length) {
pack.labels = [];
@@ -1206,7 +1206,7 @@ export function resolveVersionConflicts(mapVersion) {
const transform = textPath.getAttribute("transform");
// Get path points from the referenced path
- const href = textPath.getAttribute("href");
+ const href = textPath.getAttribute("xlink:href") || textPath.getAttribute("href");
if (!href) return;
const pathId = href.replace("#", "");
@@ -1216,9 +1216,9 @@ export function resolveVersionConflicts(mapVersion) {
const d = pathElement.getAttribute("d");
if (!d) return;
- // Parse path data to extract points (simplified - assumes M and L commands)
+ // Parse path data to extract points(M, L and C commands)
const pathPoints = [];
- const commands = d.match(/[MLZ][^MLZ]*/g);
+ const commands = d.match(/[MLC][^MLC]*/g);
if (commands) {
commands.forEach(cmd => {
const type = cmd[0];
@@ -1227,6 +1227,11 @@ export function resolveVersionConflicts(mapVersion) {
if (coords.length >= 2) {
pathPoints.push([coords[0], coords[1]]);
}
+ } else if (type === "C") {
+ const coords = cmd.slice(1).trim().split(/[\s,]+/).map(Number);
+ if (coords.length >= 6) {
+ pathPoints.push([coords[4], coords[5]]);
+ }
}
});
}